==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_entities/physicalinventoryline_001/PhysicalInventoryLine.java <==

package net.datastream.schemas.mp_entities.physicalinventoryline_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONLINEID;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPECTEDQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHYSICALQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionlineid",
    "partid",
    "bin",
    "lot",
    "expectedquantity",
    "physicalquantity",
    "manufacturerid",
    "manufacturerpartcode",
    "storeid"
})
@XmlRootElement(name = "PhysicalInventoryLine")
public class PhysicalInventoryLine {

    @XmlElement(name = "TRANSACTIONLINEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONLINEID transactionlineid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "EXPECTEDQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expectedquantity;
    @XmlElement(name = "PHYSICALQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY physicalquantity;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété transactionlineid.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public TRANSACTIONLINEID getTRANSACTIONLINEID() {
        return transactionlineid;
    }

    /**
     * Définit la valeur de la propriété transactionlineid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public void setTRANSACTIONLINEID(TRANSACTIONLINEID value) {
        this.transactionlineid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété bin.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Définit la valeur de la propriété bin.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Obtient la valeur de la propriété lot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Définit la valeur de la propriété lot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Obtient la valeur de la propriété expectedquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPECTEDQUANTITY() {
        return expectedquantity;
    }

    /**
     * Définit la valeur de la propriété expectedquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPECTEDQUANTITY(QUANTITY value) {
        this.expectedquantity = value;
    }

    /**
     * Obtient la valeur de la propriété physicalquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHYSICALQUANTITY() {
        return physicalquantity;
    }

    /**
     * Définit la valeur de la propriété physicalquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHYSICALQUANTITY(QUANTITY value) {
        this.physicalquantity = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Définit la valeur de la propriété manufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerpartcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Définit la valeur de la propriété manufacturerpartcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/physicalinventoryline_001/PhysicalInventoryLine.java <==

package net.datastream.schemas.mp_entities.physicalinventoryline_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONLINEID;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPECTEDQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHYSICALQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionlineid",
    "partid",
    "bin",
    "lot",
    "expectedquantity",
    "physicalquantity",
    "manufacturerid",
    "manufacturerpartcode",
    "storeid"
})
@XmlRootElement(name = "PhysicalInventoryLine")
public class PhysicalInventoryLine {

    @XmlElement(name = "TRANSACTIONLINEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONLINEID transactionlineid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "EXPECTEDQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expectedquantity;
    @XmlElement(name = "PHYSICALQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY physicalquantity;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the transactionlineid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public TRANSACTIONLINEID getTRANSACTIONLINEID() {
        return transactionlineid;
    }

    /**
     * Sets the value of the transactionlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public void setTRANSACTIONLINEID(TRANSACTIONLINEID value) {
        this.transactionlineid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Sets the value of the lot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Gets the value of the expectedquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPECTEDQUANTITY() {
        return expectedquantity;
    }

    /**
     * Sets the value of the expectedquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPECTEDQUANTITY(QUANTITY value) {
        this.expectedquantity = value;
    }

    /**
     * Gets the value of the physicalquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHYSICALQUANTITY() {
        return physicalquantity;
    }

    /**
     * Sets the value of the physicalquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHYSICALQUANTITY(QUANTITY value) {
        this.physicalquantity = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the manufacturerpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Sets the value of the manufacturerpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
